@@ -7,5 +7,10 @@ Features emotion detection, character voice mapping, and professional audio outp
 For system TTS fallback support, see reader-small package.
 """
 
-__version__ = "0.1.4"
-__author__ = "danielcorsano"
\ No newline at end of file
+__version__ = "0.1.5"
+__author__ = "danielcorsano"
+
+# Public API
+from .api import Reader, convert, list_voices
+
+__all__ = ["Reader", "convert", "list_voices"]
\ No newline at end of file
